[PATCH 1/1] doc: fix references to driver-model

Heinrich Schuchardt xypron.glpk at gmx.de
Tue Feb 25 21:35:39 CET 2020


Fix some errors pointed out by 'make refcheckdocs'.

Signed-off-by: Heinrich Schuchardt <xypron.glpk at gmx.de>
---
 doc/README.drivers.eth     | 2 +-
 doc/README.fdt-control     | 2 +-
 drivers/i2c/davinci_i2c.c  | 2 +-
 drivers/i2c/kona_i2c.c     | 2 +-
 drivers/i2c/sh_i2c.c       | 2 +-
 drivers/i2c/soft_i2c.c     | 2 +-
 tools/dtoc/dtb_platdata.py | 4 ++--
 tools/dtoc/dtoc.py         | 2 +-
 8 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/doc/README.drivers.eth b/doc/README.drivers.eth
index 1a9a23b51b..acaf11fea3 100644
--- a/doc/README.drivers.eth
+++ b/doc/README.drivers.eth
@@ -2,7 +2,7 @@

 This guide describes to the old way of doing things. No new Ethernet drivers
 should be implemented this way. All new drivers should be written against the
-U-Boot core driver model. See doc/driver-model/README.txt
+U-Boot core driver model. See doc/driver-model/index.rst.

 -----------------------
  Ethernet Driver Guide
diff --git a/doc/README.fdt-control b/doc/README.fdt-control
index e53cf51875..424d13fc5b 100644
--- a/doc/README.fdt-control
+++ b/doc/README.fdt-control
@@ -182,7 +182,7 @@ U-Boot can be divided into three phases: TPL, SPL and U-Boot proper.

 The full device tree is available to U-Boot proper, but normally only a subset
 (or none at all) is available to TPL and SPL. See 'Pre-Relocation Support' and
-'SPL Support' in doc/driver-model/README.txt for more details.
+'SPL Support' in doc/driver-model/design.rst for more details.


 Using several DTBs in the SPL (CONFIG_SPL_MULTI_DTB)
diff --git a/drivers/i2c/davinci_i2c.c b/drivers/i2c/davinci_i2c.c
index 2c77234c60..edc40f706c 100644
--- a/drivers/i2c/davinci_i2c.c
+++ b/drivers/i2c/davinci_i2c.c
@@ -8,7 +8,7 @@
  * --------------------------------------------------------
  *
  * NOTE: This driver should be converted to driver model before June 2017.
- * Please see doc/driver-model/i2c-howto.txt for instructions.
+ * Please see doc/driver-model/i2c-howto.rst for instructions.
  */

 #include <common.h>
diff --git a/drivers/i2c/kona_i2c.c b/drivers/i2c/kona_i2c.c
index 0726b4c956..8e31481c0f 100644
--- a/drivers/i2c/kona_i2c.c
+++ b/drivers/i2c/kona_i2c.c
@@ -3,7 +3,7 @@
  * Copyright 2013 Broadcom Corporation.
  *
  * NOTE: This driver should be converted to driver model before June 2017.
- * Please see doc/driver-model/i2c-howto.txt for instructions.
+ * Please see doc/driver-model/i2c-howto.rst for instructions.
  */

 #include <common.h>
diff --git a/drivers/i2c/sh_i2c.c b/drivers/i2c/sh_i2c.c
index b69d213593..834f1f2179 100644
--- a/drivers/i2c/sh_i2c.c
+++ b/drivers/i2c/sh_i2c.c
@@ -4,7 +4,7 @@
  * Copyright (C) 2011, 2013 Nobuhiro Iwamatsu <nobuhiro.iwamatsu.yj at renesas.com>
  *
  * NOTE: This driver should be converted to driver model before June 2017.
- * Please see doc/driver-model/i2c-howto.txt for instructions.
+ * Please see doc/driver-model/i2c-howto.rst for instructions.
  */

 #include <common.h>
diff --git a/drivers/i2c/soft_i2c.c b/drivers/i2c/soft_i2c.c
index 7f0303cc05..9ad1c281ff 100644
--- a/drivers/i2c/soft_i2c.c
+++ b/drivers/i2c/soft_i2c.c
@@ -12,7 +12,7 @@
  * Neil Russell.
  *
  * NOTE: This driver should be converted to driver model before June 2017.
- * Please see doc/driver-model/i2c-howto.txt for instructions.
+ * Please see doc/driver-model/i2c-howto.rst for instructions.
  */

 #include <common.h>
diff --git a/tools/dtoc/dtoc.py b/tools/dtoc/dtoc.py
index b3596a5918..f31cba900e 100755
--- a/tools/dtoc/dtoc.py
+++ b/tools/dtoc/dtoc.py
@@ -22,7 +22,7 @@ Dtoc produces two output files:
 This tool is used in U-Boot to provide device tree data to SPL without
 increasing the code size of SPL. This supports the CONFIG_SPL_OF_PLATDATA
 options. For more information about the use of this options and tool please
-see doc/driver-model/of-plat.txt
+see doc/driver-model/of-plat.rst
 """

 from __future__ import print_function
diff --git a/tools/dtoc/dtb_platdata.py b/tools/dtoc/dtb_platdata.py
index 037e82c8bb..90a9e1a626 100644
--- a/tools/dtoc/dtb_platdata.py
+++ b/tools/dtoc/dtb_platdata.py
@@ -423,7 +423,7 @@ class DtbPlatdata(object):

         This writes out the body of a header file consisting of structure
         definitions for node in self._valid_nodes. See the documentation in
-        README.of-plat for more information.
+        doc/driver-model/of-plat.rst for more information.
         """
         self.out_header()
         self.out('#include <stdbool.h>\n')
@@ -527,7 +527,7 @@ class DtbPlatdata(object):
         U_BOOT_DEVICE() declarations for each valid node. Where a node has
         multiple compatible strings, a #define is used to make them equivalent.

         See the documentation in doc/driver-model/of-plat.txt for more
         information.
         """
         self.out_header()
@@ -527,7 +527,7 @@ class DtbPlatdata(object):
         multiple compatible strings, a #define is used to make them equivalent.

-        See the documentation in doc/driver-model/of-plat.txt for more
+        See the documentation in doc/driver-model/of-plat.rst for more
         information.
         """
--
2.25.0



More information about the U-Boot mailing list